# Input File Parser

The inpParser module provides functions that allow you to parse an Abaqus input file.

## Create input files

```{eval-rst}
.. autoclass:: abaqus.InputFileParser.InputFile.InputFile
    :noindex:
```

## Other Classes

```{eval-rst}

.. toggle::

    .. automembers:: abaqus.InputFileParser
        :recursive:
        :exclude: InputFile
```
